(function () {
  var EFSJsBridge = window.EFSJsBridge || (window.EFSJsBridge = {});
  var JSBRIDGE_PROTOCOL = 'EFSJsBridge';

  var cp = '{{cp}}';
  var ci = '{{ci}}';
  var cv = '{{cv}}';
  var deviceId = '{{deviceId}}';
  var uid = '{{uid}}';
  var token = '{{token}}';
  var api_host = '{{api_host}}';

  function _call(action, params) {
    var paramsStr = params || '';
    if (params && typeof params === 'object') {
      paramsStr = JSON.stringify(params);
    }
    var url = JSBRIDGE_PROTOCOL + '://' + action + '?' + paramsStr;

    var iframe = document.createElement("iframe");
    iframe.src = url;
    iframe.style.display = 'none';
    document.body.appendChild(iframe);
    iframe.parentNode.removeChild(iframe);
    iframe = null;
  }

  function _parseOpt(opt) {
    if (opt) {
      var keys = Object.keys(opt);
      for (var i = 0; i < keys.length; i++) {
        var key = keys[i];
        if (opt.hasOwnProperty(key) && typeof opt[key] === 'function') {
          opt[key] = opt[key].toString();
        }
      }
    }
    return opt;
  }

  EFSJsBridge.Common = {
    getUserInfo: function () {
      return {
        uid: uid,
        token: token,
        deviceId: deviceId
      };
    },
    getClientInfo: function () {
      return {
        api_host: api_host,
        cp: cp,
        cv: cv,
        ci: ci
      };
    },
    displayInfobar: function (type, info) {
      _call('infobar', {
        type: type,
        info: info
      });
    },

    navigateTo: function (type, data) {
      _call('navigateTo', {
        type: type,
        data: data,
      });
    },
    closeWindow: function () {
      _call('closeWindow');
    },

    dispatchEvent: function (eventName) {
      const event = new Event(eventName);
      document.dispatchEvent(event);
    },

  };

  EFSJsBridge.News = {
    onNewsClicked: function (id) {
      _call('onNewsClicked', {
        id: id,
      });
    },

    onNewsScrolled: function () {
      _call('onNewsScrolled');
    }
  }

  EFSJsBridge.Order = {
    notify: function (orderId) {
      _call('order/notify', {
        orderId: orderId
      });
    }
  };

  EFSJsBridge.Utils = {
    savePhoto: function (imgUrl, opt) {
      opt = _parseOpt(opt);
      _call('savePhoto', {
        imgUrl: imgUrl,
        opt: opt,
      });
    },

    saveToClipboard: function (text, opt) {
      opt = _parseOpt(opt);
      _call('saveToClipboard', {
        text: text,
        opt: opt,
      });
    },

    showShareMenu: function (opt) {
      opt = _parseOpt(opt);
      _call('showShareMenu', {
        opt: opt,
      });
    },

    shareWechat: function (opt) {
      opt = _parseOpt(opt);
      _call('shareWechat', {
        opt: opt,
      });
    },
    shareWechatMoment: function (opt) {
      opt = _parseOpt(opt);
      _call('shareWechatMoment', {
        opt: opt,
      });
    },
    shareWxMiniProgram: function (opt) {
      opt = _parseOpt(opt);
      _call('shareWxMiniProgram', {
        opt: opt,
      });
    },
    openWxMini: function (opt) {
      opt = _parseOpt(opt);
      _call('openWxMini', {
        opt: opt,
      });
    },

    shareWxMiniProgram: function (info, callback) {
      _call('shareWxMiniProgram', {
        info: info,
        callback: callback,
      });
    }

  };

  document.dispatchEvent(new Event('EFSJsBridgeReady'));
})();